### This display all variables

(see src/hatch_ci/tools.py:get_data)

- **ctx.version**  0.1.3b48
- **ctx.current**  0.1.3
- **ctx.ref**      refs/heads/beta/0.1.3
- **ctx.branch**   beta/0.1.3
- **ctx.sha**      5e497f6336abac20c0cf19493da7c16c40deccf3
- **ctx.build**    48
- **ctx.runid**    7920229635
- **ctx.workflow** beta